@@ -1,4 +1,4 @@
-'''The dagster-airflow operators.'''
+"""The dagster-airflow operators."""
 from dagster_airflow.operators.util import invoke_steps_within_python_operator
 from dagster_airflow.vendor.python_operator import PythonOperator
 
@@ -16,5 +16,5 @@ class DagsterPythonOperator(PythonOperator):
             python_callable=python_callable,
             dag=dagster_operator_parameters.dag,
             *args,
-            **kwargs
+            **kwargs,
         )
